# opticalglass
## Tools for reading commercial optical glass catalogs

This package is a set of python scripts for reading the excel spreadsheets published by the major commercial optical glass manufacturers.

The package currently supports

* Hoya
* Ohara
* Schott

All rights and ownership of the data is retained by the original owners, i.e the respective manufacturers.